@@ -5,9 +5,22 @@ use v5.20;
 use experimental qw/ signatures /;
 package YAML::Tidy::Config;
 
-our $VERSION = '0.003_001'; # TRIAL VERSION
+our $VERSION = '0.003_002'; # TRIAL VERSION
 
 use Cwd;
+use YAML::PP::Common qw/
+    YAML_PLAIN_SCALAR_STYLE YAML_SINGLE_QUOTED_SCALAR_STYLE
+    YAML_DOUBLE_QUOTED_SCALAR_STYLE YAML_LITERAL_SCALAR_STYLE
+    YAML_FOLDED_SCALAR_STYLE
+    YAML_FLOW_SEQUENCE_STYLE YAML_FLOW_MAPPING_STYLE
+/;
+my %stylemap = (
+    plain => YAML_PLAIN_SCALAR_STYLE,
+    single => YAML_SINGLE_QUOTED_SCALAR_STYLE,
+    double => YAML_DOUBLE_QUOTED_SCALAR_STYLE,
+#    literal => YAML_LITERAL_SCALAR_STYLE,
+#    folded => YAML_FOLDED_SCALAR_STYLE,
+);
 
 sub new($class, %args) {
     my $yaml;
@@ -51,6 +64,7 @@ sub new($class, %args) {
     my $indent = delete $cfg->{indentation} || {};
     $indent->{spaces} = $overridespaces if defined $overridespaces;
     $indent->{spaces} //= 2; # TODO support keeping original indent
+    $indent->{'block-sequence-in-mapping'} //= 0;
     my $trimtrailing = $cfg->{'trailing-spaces'} || '';
     if ($trimtrailing eq 'fix') {
         $trimtrailing = 1;
@@ -58,6 +72,11 @@ sub new($class, %args) {
     else {
         $trimtrailing = 0;
     }
+    my $scalarstyle = { default => YAML_PLAIN_SCALAR_STYLE };
+    if (my $scalar = delete $cfg->{'scalar-style'}) {
+        my $default = $scalar->{default};
+        $scalarstyle->{default} = $default ? $stylemap{ $default } : undef;
+    }
 
     delete @args{qw/ configfile configdata /};
     if (my @unknown = keys %args) {
@@ -69,6 +88,7 @@ sub new($class, %args) {
         trimtrailing => $trimtrailing,
         header => delete $cfg->{header} // 'keep',
         footer => delete $cfg->{footer} // 'keep',
+        scalar_style => $scalarstyle,
     }, $class;
     return $self;
 }
@@ -84,6 +104,9 @@ sub _homedir($class) {
 sub indent($self) {
     return $self->{indentation}->{spaces};
 }
+sub indent_seq_in_map($self) {
+    return $self->{indentation}->{'block-sequence-in-mapping'};
+}
 
 sub trimtrailing($self) {
     return $self->{trimtrailing};
@@ -113,14 +136,21 @@ sub removefooter($self) {
     return $footer ? 0 : 1;
 }
 
+sub default_scalar_style($self) {
+    return $self->{scalar_style}->{default};
+}
+
 sub standardcfg {
     my $yaml = <<'EOM';
 ---
 v: v0.1
 indentation:
   spaces: 2
+  block-sequence-in-mapping: 0
 trailing-spaces: fix
 header: true
+scalar-style:
+    default: plain
 EOM
 }
 
